%define build_type %(if [[ ${BRANCH_NAME} = *release/* ]]; then echo release; else echo feature; fi)
%define osbuilder_release %{agent_release}

%global cri_o_min 1.17
%global cri_o_max 1.19
%global kata_runtime_version %{version}-1%{dist}   
%global kata_proxy_version %{version}-1%{dist}
%global kata_shim_version %{version}-1%{dist}
%global kata_throttler_version %{version}-1%{dist}

# this if statement is required such that when we merged
# kata meta RPM, it will correctly pointing the kata-image
# that is only and already available in a stable repo (release)
%if %{?oraclelinux} == 8 && %{?build_type} == release
%global kata_image_version 1.11.5-1.1.ol8_202101151826 
%endif

%if %{?oraclelinux} == 7 && %{?build_type} == release
%global kata_image_version 1.11.5-1.1.ol7_202101151825 
%endif

%if %{?oraclelinux} == 8
%global kata_image_version 1.11.5-1.1.ol8_202101151826 
%endif

%if %{?oraclelinux} == 7
%global kata_image_version 1.11.5-1.1.ol7_202101151825 
%endif

%global kernel_uek_container_min 5.4.17-2036.100.6.1%{dist}
%global kernel_uek_container_max 5.5
%global kernel_uek_min 4.14
%global kernel_uek_max 5.5
%global cri_tools_min 1.17
%global cri_tools_max 1.19
%global qemu_kvm_min 4.1.1
%global qemu_min 15:3.1
%global qemu_max 15:4.4

Name:      kata
Version:   1.11.5
Release:   2%{?dist}
Vendor:    Oracle America
Summary:   meta rpm to ease cri-o and kata installation for olcne
Group:     Development/Tools
License:   UPL

Requires: cri-o >= %{cri_o_min}
Requires: cri-o < %{cri_o_max}
Requires: kata-runtime = %{kata_runtime_version}
Requires: kata-proxy = %{kata_proxy_version}
Requires: kata-shim = %{kata_shim_version}
Requires: kata-ksm-throttler = %{kata_throttler_version}
Requires: kata-image = %{kata_image_version}
Requires: kernel-uek-container >= %{kernel_uek_container_min}
Requires: kernel-uek-container < %{kernel_uek_container_max}
Requires: kernel-uek >= %{kernel_uek_min}
Requires: kernel-uek < %{kernel_uek_max}
Requires: cri-tools >= %{cri_tools_min}
Requires: cri-tools < %{cri_tools_max}
%if %{?oraclelinux} == 7
Requires: qemu >= %{qemu_min}
Requires: qemu < %{qemu_max}
%endif
%if %{?oraclelinux} == 8
# OL8 doesn't play well with qemu_kvm_max
# it will complain with:
# Error: transaction check vs depsolve:
# qemu-kvm < 5.0.0 is needed by kata-1.11.3-3.el8.x86_64
Requires: qemu-kvm >= %{qemu_kvm_min}
%endif


%description
A meta rpm to help facilitate the installation of cri-o and kata related components.

%prep
echo BRANCH_NAME=%{build_type}

%install

%files

%doc

%post
# we need to make some baseline adjustments to the crio config post installation
checkCrioConf () {
  # arg1 config section, arg2 keyword, arg3 value
  # if keyword is missing, add it and value to config section
  if ! grep -q "^$2" %{_sysconfdir}/crio/crio.conf; then
    sed -i \
        -e "/^$1/a $2 = $3" \
        %{_sysconfdir}/crio/crio.conf
  else
  # keyword is present, ensure it has the correct value
    sed -i \
        -e "s/^$2.*/$2 = $3/" \
        %{_sysconfdir}/crio/crio.conf
  fi
}

checkCrioConf "\[crio.runtime\]" "manage_network_ns_lifecycle" "true"
checkCrioConf "\[crio.runtime\]" "selinux" "false"
checkCrioConf "\[crio.image\]" "registries" "\[\"docker.io\", \"container-registry.oracle.com\"\]"
checkCrioConf "\[crio.image\]" "pause_image_auth_file" "\"\/run\/containers\/0\/auth.json\""
checkCrioConf "\[crio.image\]" "pause_image " "\"container-registry.oracle.com\/kubernetes\/pause:3.1\""

# insert extra config section if it's missing
if ! grep -q "\[crio.runtime.runtimes.kata\]" %{_sysconfdir}/crio/crio.conf; then
  sed -i \
      -e '/\[crio.runtime.runtimes.runc\]/i\
\[crio.runtime.runtimes.kata\]\
runtime_path = \"\/usr\/bin\/kata-runtime\"\
runtime_type = \"oci\"\n'\
      %{_sysconfdir}/crio/crio.conf
fi

%changelog
* Fri Jan 15 2021 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.11.5-2
- Update to kata 1.11.5

* Thu Nov 12 2020 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.11.3-4
- Use kernel-uek-container-5.4.17-2036.100.6.1

* Thu Oct 29 2020 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.11.3-3
- Bump OL8 qemu-kvm-min

* Tue Oct 27 2020 Durai Govindasamy <durai.vattakalvalasu.govindas@oracle.com> - 1.11.3-2
- Added OL8 changes

* Mon Oct 12 2020 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.11.3-1
- Update to kata 1.11.3
